# jupyda
Ipython extension to execute CUDA C code in Jupyter notebook.
Now you can easily use the power of Google colab GPUs with your CUDA C code.

See this example colab [notebook](https://colab.research.google.com/drive/1NWnRqRfl3yY-DiezTwqS1NH-YVZptqu6).
